pub struct KeyValue<'a> {
pub key: Cow<'a, [u8]>,
pub value: Cow<'a, [u8]>,
}Fields
key: Cow<'a, [u8]>value: Cow<'a, [u8]>Trait Implementations
Sourceimpl<'a> BorshDeserialize for KeyValue<'a>
impl<'a> BorshDeserialize for KeyValue<'a>
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl<'a> BorshSerialize for KeyValue<'a>
impl<'a> BorshSerialize for KeyValue<'a>